@@ -1,7 +1,7 @@
 import functools
 import json
-import os
 import multiprocessing
+import os
 from threading import Thread
 
 from ._colorizer import Colorizer
@@ -189,6 +189,8 @@ class Handler:
                     return
                 self._queue.put(None)
                 self._thread.join()
+                if hasattr(self._queue, "close"):
+                    self._queue.close()
 
             self._sink.stop()
 
@@ -255,7 +257,7 @@ class Handler:
             },
         }
 
-        return json.dumps(serializable, default=str) + "\n"
+        return json.dumps(serializable, default=str, ensure_ascii=False) + "\n"
 
     def _queued_writer(self):
         message = None
