@@ -34,12 +34,12 @@
 .. |timedelta| replace:: :class:`datetime.timedelta`
 .. |open| replace:: :func:`open()`
 .. |logging| replace:: :mod:`logging`
+.. |signal| replace:: :mod:`signal`
 .. |contextvars| replace:: :mod:`contextvars`
 .. |Thread.run| replace:: :meth:`Thread.run()<threading.Thread.run()>`
 .. |Exception| replace:: :class:`Exception`
-.. |locale.getpreferredencoding| replace:: :func:`locale.getpreferredencoding()`
 .. |AbstractEventLoop| replace:: :class:`AbstractEventLoop<asyncio.AbstractEventLoop>`
-.. |asyncio.get_event_loop| replace:: :func:`asyncio.get_event_loop()`
+.. |asyncio.get_running_loop| replace:: :func:`asyncio.get_running_loop()`
 .. |asyncio.run| replace:: :func:`asyncio.run()`
 .. |loop.run_until_complete| replace::
     :meth:`loop.run_until_complete()<asyncio.loop.run_until_complete()>`
@@ -69,26 +69,26 @@
 .. _@sdispater: https://github.com/sdispater
 .. _@Qix-: https://github.com/Qix-
 .. _Formatting directives: https://docs.python.org/3/library/string.html#format-string-syntax
+.. _reentrant: https://en.wikipedia.org/wiki/Reentrancy_(computing)
 """
-import asyncio
 import builtins
 import contextlib
 import functools
-import inspect
 import itertools
 import logging
 import re
 import sys
 import warnings
 from collections import namedtuple
-from inspect import isclass
+from inspect import isclass, iscoroutinefunction, isgeneratorfunction
 from multiprocessing import current_process
 from os.path import basename, splitext
 from threading import current_thread
 
-from . import _colorama, _defaults, _filters
+from . import _asyncio_loop, _colorama, _defaults, _filters
 from ._better_exceptions import ExceptionFormatter
 from ._colorizer import Colorizer
+from ._contextvars import ContextVar
 from ._datetime import aware_now
 from ._error_interceptor import ErrorInterceptor
 from ._file_sink import FileSink
@@ -103,13 +103,6 @@ if sys.version_info >= (3, 6):
 else:
     from pathlib import PurePath as PathLike
 
-if sys.version_info >= (3, 7):
-    from contextvars import ContextVar
-elif sys.version_info >= (3, 5, 3):
-    from aiocontextvars import ContextVar
-else:
-    from contextvars import ContextVar
-
 
 Level = namedtuple("Level", ["name", "no", "color", "icon"])
 
@@ -206,8 +199,8 @@ class Logger:
 
     Handlers to which the logger sends log messages are added using the |add| method. Note that you
     can use the |Logger| right after import as it comes pre-configured (logs are emitted to
-    |sys.stderr| by default). Messages can be logged with different severity levels and using braces
-    attributes like the |str.format| method do.
+    |sys.stderr| by default). Messages can be logged with different severity levels and they can be
+    formatted using curly braces (it uses |str.format| under the hood).
 
     When a message is logged, a "record" is associated with it. This record is a dict which contains
     information about the logging context: time, function, file, line, thread, level... It also
@@ -284,7 +277,8 @@ class Logger:
         ----------
         loop : |AbstractEventLoop|, optional
             The event loop in which the asynchronous logging task will be scheduled and executed. If
-            ``None``, the loop returned by |asyncio.get_event_loop| is used.
+            ``None``, the loop used is the one returned by |asyncio.get_running_loop| at the time of
+            the logging call (task is discarded if there is no loop currently running).
 
 
         If and only if the sink is a file path, the following parameters apply:
@@ -309,8 +303,7 @@ class Logger:
             The buffering policy as for built-in |open| function. It defaults to ``1`` (line
             buffered file).
         encoding : |str|, optional
-            The file encoding as for built-in |open| function. If ``None``, it defaults to
-            |locale.getpreferredencoding|.
+            The file encoding as for built-in |open| function. It defaults to ``"utf8"``.
         **kwargs
             Others parameters are passed to the built-in |open| function.
 
@@ -320,6 +313,11 @@ class Logger:
             An identifier associated with the added sink and which should be used to
             |remove| it.
 
+        Raises
+        ------
+        ValueError
+            If any of the arguments passed to configure the sink is invalid.
+
         Notes
         -----
         Extended summary follows.
@@ -346,8 +344,9 @@ class Logger:
         - A built-in |Handler| like ``logging.StreamHandler``. In such a case, the `Loguru` records
           are automatically converted to the structure expected by the |logging| module.
 
-        Note that you should avoid using  the ``logger`` inside any of your sinks as this would
-        result in infinite recursion or dead lock if the module's sink was not explicitly disabled.
+        Note that the logging functions are not `reentrant`_. This means you should avoid using
+        the ``logger`` inside any of your sinks or from within |signal| handlers. Otherwise, you
+        may face deadlock if the module's sink was not explicitly disabled.
 
         .. _message:
 
@@ -790,7 +789,7 @@ class Logger:
             encoding = getattr(sink, "encoding", None)
             terminator = ""
             exception_prefix = "\n"
-        elif inspect.iscoroutinefunction(sink):
+        elif iscoroutinefunction(sink) or iscoroutinefunction(getattr(sink, "__call__", None)):
             name = getattr(sink, "__name__", None) or repr(sink)
 
             if colorize is None:
@@ -804,9 +803,16 @@ class Logger:
             # at each logging call, which is much more convenient. However, coroutine can't access
             # running loop in Python 3.5.2 and earlier versions, see python/asyncio#452.
             if enqueue and loop is None:
-                loop = asyncio.get_event_loop()
+                try:
+                    loop = _asyncio_loop.get_running_loop()
+                except RuntimeError as e:
+                    raise ValueError(
+                        "An event loop is required to add a coroutine sink with `enqueue=True`, "
+                        "but but none has been passed as argument and none is currently running."
+                    ) from e
 
-            wrapped_sink = AsyncSink(sink, loop, error_interceptor)
+            coro = sink if iscoroutinefunction(sink) else sink.__call__
+            wrapped_sink = AsyncSink(coro, loop, error_interceptor)
             encoding = "utf8"
             terminator = "\n"
             exception_prefix = ""
@@ -865,7 +871,7 @@ class Logger:
                 if levelno_ < 0:
                     raise ValueError(
                         "The filter dict contains a module '%s' associated to an invalid level, "
-                        "it should be a positive interger, not: '%d'" % (module, levelno_)
+                        "it should be a positive integer, not: '%d'" % (module, levelno_)
                     )
                 level_per_module[module] = levelno_
             filter_func = functools.partial(
@@ -1022,8 +1028,8 @@ class Logger:
 
         The returned object should be awaited before the end of a coroutine executed by
         |asyncio.run| or |loop.run_until_complete| to ensure all asynchronous logging messages are
-        processed. The function |asyncio.get_event_loop| is called beforehand, only tasks scheduled
-        in the same loop that the current one will be awaited by the method.
+        processed. The function |asyncio.get_running_loop| is called beforehand, only tasks
+        scheduled in the same loop that the current one will be awaited by the method.
 
         Returns
         -------
@@ -1199,14 +1205,14 @@ class Logger:
             def __call__(_, function):
                 catcher = Catcher(True)
 
-                if inspect.iscoroutinefunction(function):
+                if iscoroutinefunction(function):
 
                     async def catch_wrapper(*args, **kwargs):
                         with catcher:
                             return await function(*args, **kwargs)
                         return default
 
-                elif inspect.isgeneratorfunction(function):
+                elif isgeneratorfunction(function):
 
                     def catch_wrapper(*args, **kwargs):
                         with catcher:
@@ -1914,7 +1920,7 @@ class Logger:
             "function": code.co_name,
             "level": RecordLevel(level_name, level_no, level_icon),
             "line": frame.f_lineno,
-            "message": message,
+            "message": str(message),
             "module": splitext(file_name)[0],
             "name": name,
             "process": RecordProcess(process.ident, process.name),
@@ -1941,7 +1947,7 @@ class Logger:
             if args or kwargs:
                 colored_message = Colorizer.prepare_message(message, args, kwargs)
             else:
-                colored_message = Colorizer.prepare_simple_message(message)
+                colored_message = Colorizer.prepare_simple_message(str(message))
             log_record["message"] = colored_message.stripped
         elif args or kwargs:
             colored_message = None
