@@ -1,15 +1,17 @@
 import asyncio
 import contextlib
-import loguru
 import logging
-import itertools
-import pytest
 import os
-import subprocess
 import sys
+import threading
 import time
+import traceback
 import warnings
 
+import pytest
+
+import loguru
+
 if sys.version_info < (3, 5, 3):
 
     def run(coro):
@@ -44,6 +46,27 @@ def parse(text, *, strip=False, strict=True):
         return parser.colorize(tokens, "")
 
 
+@contextlib.contextmanager
+def default_threading_excepthook():
+    if not hasattr(threading, "excepthook"):
+        yield
+        return
+
+    # Pytest added "PytestUnhandledThreadExceptionWarning", we need to
+    # remove it temporarily for somes tests checking exceptions in threads.
+
+    def excepthook(args):
+        print("Exception in thread:", file=sys.stderr, flush=True)
+        traceback.print_exception(
+            args.exc_type, args.exc_value, args.exc_traceback, file=sys.stderr
+        )
+
+    old_excepthook = threading.excepthook
+    threading.excepthook = excepthook
+    yield
+    threading.excepthook = old_excepthook
+
+
 @pytest.fixture(scope="session", autouse=True)
 def check_env_variables():
     for var in os.environ:
@@ -151,11 +174,11 @@ def make_logging_logger(name, handler, fmt="%(message)s", level="DEBUG"):
 
 @pytest.fixture
 def f_globals_name_absent(monkeypatch):
-    getframe_ = loguru._get_frame.get_frame
+    getframe_ = loguru._get_frame.load_get_frame_function()
 
     def patched_getframe(*args, **kwargs):
         frame = getframe_(*args, **kwargs)
-        monkeypatch.delitem(frame.f_globals, "__name__", raising=False)
+        frame.f_globals.pop("__name__", None)
         return frame
 
     monkeypatch.setattr(loguru._logger, "get_frame", patched_getframe)
