@@ -1,5 +1,6 @@
-import os, sys, sysconfig
-
+import os
+import sys
+import sysconfig
 
 usersite = os.path.abspath(os.path.join(os.path.dirname(__file__), "usersite"))
 sys.path.append(usersite)
