@@ -1,9 +1,13 @@
-from loguru import logger
-import pytest
-import time
+import pickle
 import re
 import sys
-import pickle
+import time
+
+import pytest
+
+from loguru import logger
+
+from .conftest import default_threading_excepthook
 
 
 class NotPicklable:
@@ -39,7 +43,7 @@ def test_enqueue():
     logger.add(sink, format="{message}", enqueue=True)
     logger.debug("Test")
     assert len(x) == 0
-    time.sleep(0.2)
+    logger.complete()
     assert len(x) == 1
     assert x[0] == "Test\n"
 
@@ -59,7 +63,7 @@ def test_enqueue_with_exception():
         logger.exception("Error")
 
     assert len(x) == 0
-    time.sleep(0.2)
+    logger.complete()
     assert len(x) == 1
     lines = x[0].splitlines()
 
@@ -131,7 +135,6 @@ def test_not_caught_exception_queue_put(writer, capsys):
     logger.remove()
 
     out, err = capsys.readouterr()
-    lines = err.strip().splitlines()
     assert writer.read() == "It's fine\n"
     assert out == ""
     assert err == ""
@@ -140,10 +143,11 @@ def test_not_caught_exception_queue_put(writer, capsys):
 def test_not_caught_exception_queue_get(writer, capsys):
     logger.add(writer, enqueue=True, catch=False, format="{message}")
 
-    logger.info("It's fine")
-    logger.bind(broken=NotUnpicklable()).info("Bye bye...")
-    logger.info("It's not fine")
-    logger.remove()
+    with default_threading_excepthook():
+        logger.info("It's fine")
+        logger.bind(broken=NotUnpicklable()).info("Bye bye...")
+        logger.info("It's not fine")
+        logger.remove()
 
     out, err = capsys.readouterr()
     lines = err.strip().splitlines()
@@ -156,10 +160,11 @@ def test_not_caught_exception_queue_get(writer, capsys):
 def test_not_caught_exception_sink_write(capsys):
     logger.add(NotWritable(), enqueue=True, catch=False, format="{message}")
 
-    logger.info("It's fine")
-    logger.bind(fail=True).info("Bye bye...")
-    logger.info("It's not fine")
-    logger.remove()
+    with default_threading_excepthook():
+        logger.info("It's fine")
+        logger.bind(fail=True).info("Bye bye...")
+        logger.info("It's not fine")
+        logger.remove()
 
     out, err = capsys.readouterr()
     lines = err.strip().splitlines()
@@ -186,8 +191,7 @@ def test_wait_for_all_messages_enqueued(capsys):
     assert err == "".join("%d\n" % i for i in range(10))
 
 
-@pytest.mark.parametrize("arg", [NotPicklable(), NotUnpicklable()])
-def test_logging_not_picklable_exception(arg):
+def test_logging_not_picklable_exception():
     exception = None
 
     def sink(message):
@@ -197,7 +201,30 @@ def test_logging_not_picklable_exception(arg):
     logger.add(sink, enqueue=True, catch=False)
 
     try:
-        raise ValueError(arg)
+        raise ValueError(NotPicklable())
+    except Exception:
+        logger.exception("Oups")
+
+    logger.remove()
+
+    type_, value, traceback_ = exception
+    assert type_ is ValueError
+    assert value is None
+    assert traceback_ is None
+
+
+@pytest.mark.skip(reason="No way to safely deserialize exception yet")
+def test_logging_not_unpicklable_exception():
+    exception = None
+
+    def sink(message):
+        nonlocal exception
+        exception = message.record["exception"]
+
+    logger.add(sink, enqueue=True, catch=False)
+
+    try:
+        raise ValueError(NotUnpicklable())
     except Exception:
         logger.exception("Oups")
 
