@@ -1,14 +1,18 @@
 import json
+import re
 import sys
+
 from loguru import logger
 
 
 class JsonSink:
     def __init__(self):
+        self.message = None
         self.dict = None
         self.json = None
 
     def write(self, message):
+        self.message = message
         self.dict = message.record
         self.json = json.loads(message)
 
@@ -22,6 +26,17 @@ def test_serialize():
     assert set(sink.dict.keys()) == set(sink.json["record"].keys())
 
 
+def test_serialize_non_ascii_characters():
+    sink = JsonSink()
+    logger.add(sink, format="{level.icon} {message}", serialize=True)
+    logger.debug("天")
+    assert re.search(r'"message": "([^\"]+)"', sink.message).group(1) == "天"
+    assert re.search(r'"text": "([^\"]+)"', sink.message).group(1) == "🐞 天\\n"
+    assert re.search(r'"icon": "([^\"]+)"', sink.message).group(1) == "🐞"
+    assert sink.json["text"] == "🐞 天\n"
+    assert sink.dict["message"] == sink.json["record"]["message"] == "天"
+
+
 def test_serialize_exception():
     sink = JsonSink()
     logger.add(sink, format="{message}", serialize=True, catch=False)
@@ -76,7 +91,7 @@ def test_serialize_exception_none_tuple():
     }
 
 
-def test_serialize_exception_instrance():
+def test_serialize_exception_instance():
     sink = JsonSink()
     logger.add(sink, format="{message}", serialize=True, catch=False)
 
