@@ -1,19 +1,20 @@
-import importlib
 import sys
+
 import loguru
+from loguru._get_frame import load_get_frame_function
 
 
 def test_with_sys_getframe(monkeypatch):
-    patched = lambda: None
-    monkeypatch.setattr(sys, "_getframe", patched)
-    get_frame_module = importlib.reload(loguru._get_frame)
-    assert get_frame_module.get_frame == patched
+    def patched():
+        return
+
+    monkeypatch.setattr(sys, "_getframe", patched())
+    assert load_get_frame_function() == patched()
 
 
 def test_without_sys_getframe(monkeypatch):
     monkeypatch.delattr(sys, "_getframe")
-    get_frame_module = importlib.reload(loguru._get_frame)
-    assert get_frame_module.get_frame == loguru._get_frame.get_frame_fallback
+    assert load_get_frame_function() == loguru._get_frame.get_frame_fallback
 
 
 def test_get_frame_fallback():
