@@ -1,11 +1,12 @@
-import loguru
-from loguru import logger
+import builtins
 import logging
-import sys
 import pathlib
 import re
+import sys
 from inspect import iscoroutinefunction
-import builtins
+
+import loguru
+from loguru import logger
 
 
 class Wrapper:
@@ -179,7 +180,12 @@ def test_standard_handler():
 def test_multiple_handlers():
     logger.add(sys.__stdout__)
     logger.add(sys.__stderr__)
-    r = "<loguru.logger handlers=[(id=0, level=10, sink=<stdout>), (id=1, level=10, sink=<stderr>)]>"
+    r = (
+        "<loguru.logger handlers=["
+        "(id=0, level=10, sink=<stdout>), "
+        "(id=1, level=10, sink=<stderr>)"
+        "]>"
+    )
     assert repr(logger) == r
 
 
